@@ -22,6 +22,9 @@ class ActionBase(with_metaclass(ABCMeta, Action)):
     Базовый класс для обработчиков запросов на поиск данных в ГАР.
     """
 
+    # Признак того, что необходимо корректировать пользовательский ввод
+    correct_keyboard_input = True
+
     @abstractmethod
     def _get_loader(self, context):
         """Возвращает загрузчик данных.
@@ -38,7 +41,8 @@ class ActionBase(with_metaclass(ABCMeta, Action)):
         }
 
     def run(self, request, context):
-        context.filter = correct_keyboard_layout(context.filter)
+        if self.correct_keyboard_input:
+            context.filter = correct_keyboard_layout(context.filter)
 
         loader = self._get_loader(context)
         rows = loader.load()
@@ -93,6 +97,7 @@ class HouseSearchAction(ParentMixin, ActionBase):
     """
 
     url = '/search/house'
+    correct_keyboard_input = False
 
     def _get_loader(self, context):
         # pylint: disable=abstract-class-instantiated
