@@ -1211,7 +1211,7 @@ Ext.m3.gar.RowsAddressView = Ext.extend(Ext.m3.gar.AddressViewBase, {
         records.forEach(function(record) {
             record.set(
                 'name',
-                record.get('shortName') + '. ' + record.get('formalName')
+                record.get('typeFullName') + ' ' + record.get('formalName')
             );
         });
     }
